/*
 * Installer by Fernando Pereira Silveira
 *
 * Derived from XpiInstaller
 * By Pike (Heavily inspired by code from Henrik Gemal and Stephen Clavering)
 */

// *** EDITABLE DATA ***
const fullName        = "Controle de Scripts";
const shortName       = "controledescripts";
const version         = "0.4";
const locales         = ["de-DE", "en-GB", "en-US", "es-AR", "es-ES", "fi-FI", "fr-FR", "it-IT", "ja-JP", "nl-NL", "pt-BR", "zh-CN", "zh-TW"];
const skins           = ["classic"];  // ["classic", "modern"]
const jarFileName     = shortName+".jar";
const silentInstall   = false; // install with no messages
// !IMPORTANT!
const jarHasSubfolder = false; // 'true' if jar folder structure is 'content/[shortName]/' or 'false' if jar folder structure is 'content/'. Got it?
var   profileInstall  = null;  // MUST enter 'true' or 'false' if silentInstall is 'true'
// *** EDITABLE DATA ***

// *** Auxiliar data ***
const profileFolder = getFolder("Profile", "chrome");
const appFolder = getFolder("chrome");
const jarSubfolder = jarHasSubfolder?shortName+"/":"";
var chromeType = null;
var installFolder = null;
var jarFolder = null;

// *** Auxiliar routines ***
if (File.exists(getFolder(profileFolder, jarFileName)))
{
	profileInstall = true;

	if (!silentInstall)
		alert("Updating "+fullName+" to version "+version+" on your profile folder.");
}
else if (!silentInstall)
	profileInstall = confirm("Do you want to install "+fullName+" "+version+" in your profile folder?\n(Cancel will install it in the application folder)");

chromeType = profileInstall?PROFILE_CHROME:DELAYED_CHROME;
installFolder = profileInstall?profileFolder:appFolder;
jarFolder = getFolder(installFolder, jarFileName);


// *** Installer ***

// Begin install
initInstall(fullName, shortName, version);
checkError("Couldn't init the installation process.", false);

// Add the JAR file
addFile(shortName, "chrome/"+jarFileName, installFolder, null);
checkError("Couldn't copy "+jarFileName+".\nVerify if you have write access to chrome folder.",false);

// Register content
registerChrome(CONTENT | chromeType, jarFolder, "content/"+jarSubfolder);

// Register locales
for (var thisOne in locales)
	registerChrome(LOCALE | chromeType, jarFolder, "locale/"+locales[thisOne]+"/"+jarSubfolder);

// Register skins
for (var thisOne in skins)
	registerChrome(SKIN | chromeType, jarFolder, "skin/"+skins[thisOne]+"/"+jarSubfolder);

// Finish install
performInstall();
checkError("Couldn't install "+fullName+".\nContact the author about this problem.", true);


// *** Functions ***
function checkError(errorMsg,isFinalMsg)
{
	var error = getLastError();

	if (isFinalMsg)
	{
		if (error != SUCCESS && error != REBOOT_NEEDED)
		{
			if (!silentInstall)
				if (error == -215)
					alert("Error "+error+"\nOne of the files being overwritten is read-only.");
				else if (error == -235)
					alert("Error "+error+"\nThere is insufficient disk space.");
				else
					alert("Error "+error+"\n"+errorMsg);
			cancelInstall(error);
		}
		else if (!silentInstall)
			alert(fullName+" "+version+" has been installed successfully!");
	}
	else if (error != SUCCESS)
	{
		if (!silentInstall)
			if (error == -215)
				alert("Error "+error+"\nOne of the files being overwritten is read-only.");
			else if (error == -235)
				alert("Error "+error+"\nThere is insufficient disk space.");
			else
				alert("Error "+error+"\n"+errorMsg);
		cancelInstall(error);
	}
}
